# coding: utf-8

"""
    IBM Guardium Data Security Center

    Use Guardium Data Security Center SDK (application programming interfaces) to interact with other applications, such as Guardium Data Protection, universal connectors, and Guardium Data Security Center reports.

    The version of the OpenAPI document: 3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from ibm_gdsc_sdk_software.models.compliance import Compliance
from ibm_gdsc_sdk_software.models.vulnerability_criticality import VulnerabilityCriticality
from ibm_gdsc_sdk_software.models.vulnerability_flow_ref import VulnerabilityFlowRef
from ibm_gdsc_sdk_software.models.vulnerability_related_asset import VulnerabilityRelatedAsset
from ibm_gdsc_sdk_software.models.vulnerability_remediation import VulnerabilityRemediation
from ibm_gdsc_sdk_software.models.vulnerability_status import VulnerabilityStatus
from ibm_gdsc_sdk_software.models.vulnerability_type import VulnerabilityType
from typing import Optional, Set
from typing_extensions import Self

class Vulnerability(BaseModel):
    """
    Vulnerability
    """ # noqa: E501
    vulnerability_id: StrictStr = Field(alias="vulnerabilityId")
    type: VulnerabilityType
    sub_type: Optional[StrictStr] = Field(default=None, alias="subType")
    title: StrictStr
    description: StrictStr
    reason: Optional[StrictStr] = None
    configuration_reason: Optional[StrictStr] = Field(default=None, alias="configurationReason")
    recommendation: Optional[StrictStr] = None
    remediation: Optional[VulnerabilityRemediation] = None
    detection_timestamp: Union[StrictFloat, StrictInt] = Field(alias="detectionTimestamp")
    criticality: VulnerabilityCriticality
    threats: Optional[List[StrictStr]] = None
    compliance: Optional[List[Compliance]] = None
    affected_asset: Optional[VulnerabilityRelatedAsset] = Field(default=None, alias="affectedAsset")
    status_history: Optional[List[VulnerabilityStatus]] = Field(default=None, alias="statusHistory")
    flow_ref: Optional[VulnerabilityFlowRef] = Field(default=None, alias="flowRef")
    related_assets: Optional[List[VulnerabilityRelatedAsset]] = Field(default=None, alias="relatedAssets")
    __properties: ClassVar[List[str]] = ["vulnerabilityId", "type", "subType", "title", "description", "reason", "configurationReason", "recommendation", "remediation", "detectionTimestamp", "criticality", "threats", "compliance", "affectedAsset", "statusHistory", "flowRef", "relatedAssets"]

    @field_validator('threats')
    def threats_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['Data Leakage', 'Ransomware', 'Compliance Violation', 'Malware', 'External Sharing']):
                raise ValueError("each list item must be one of ('Data Leakage', 'Ransomware', 'Compliance Violation', 'Malware', 'External Sharing')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Vulnerability from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of remediation
        if self.remediation:
            _dict['remediation'] = self.remediation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of affected_asset
        if self.affected_asset:
            _dict['affectedAsset'] = self.affected_asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in status_history (list)
        _items = []
        if self.status_history:
            for _item in self.status_history:
                if _item:
                    _items.append(_item.to_dict())
            _dict['statusHistory'] = _items
        # override the default output from pydantic by calling `to_dict()` of flow_ref
        if self.flow_ref:
            _dict['flowRef'] = self.flow_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in related_assets (list)
        _items = []
        if self.related_assets:
            for _item in self.related_assets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['relatedAssets'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Vulnerability from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "vulnerabilityId": obj.get("vulnerabilityId"),
            "type": obj.get("type"),
            "subType": obj.get("subType"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "reason": obj.get("reason"),
            "configurationReason": obj.get("configurationReason"),
            "recommendation": obj.get("recommendation"),
            "remediation": VulnerabilityRemediation.from_dict(obj["remediation"]) if obj.get("remediation") is not None else None,
            "detectionTimestamp": obj.get("detectionTimestamp"),
            "criticality": obj.get("criticality"),
            "threats": obj.get("threats"),
            "compliance": obj.get("compliance"),
            "affectedAsset": VulnerabilityRelatedAsset.from_dict(obj["affectedAsset"]) if obj.get("affectedAsset") is not None else None,
            "statusHistory": [VulnerabilityStatus.from_dict(_item) for _item in obj["statusHistory"]] if obj.get("statusHistory") is not None else None,
            "flowRef": VulnerabilityFlowRef.from_dict(obj["flowRef"]) if obj.get("flowRef") is not None else None,
            "relatedAssets": [VulnerabilityRelatedAsset.from_dict(_item) for _item in obj["relatedAssets"]] if obj.get("relatedAssets") is not None else None
        })
        return _obj


